@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/Throttle.pm 8775 2007-11-08T09:53:44.496906Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/Throttle.pm 31302 2007-11-29T11:52:09.725591Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 
@@ -21,10 +21,11 @@ sub send_request
     my ($c, $request) = @_;
 
     if (! $request->notes('original_host') && ! $c->throttle($request)) {
-        $c->log->debug("Request " . $request->url . " (" . $request->id . ") was throttled");
-        $c->provider->pushback_request($c, $request);
+        $c->log->debug("[THROTTLE] Request " . $request->url . " (" . $request->id . ") was throttled");
+        $c->pushback_request($request);
+        return 0;
     } else {
-        $c->next::method($request);
+        return $c->next::method($request);
     }
 }
 
