@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 3235 2007-10-13T15:50:33.445011Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 9352 2007-11-21T02:13:31.513580Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -27,7 +27,9 @@ sub setup
     $self->setup_impl_class($c);
 
     $self->loop_delay( $self->config->{loop_delay} ) if $self->config->{loop_delay};
-
+    if (! $self->config->{dns}{disable}) {
+        $self->resolver(Net::DNS::Resolver->new);
+    }
 }
 
 sub setup_impl_class
@@ -52,7 +54,6 @@ sub setup_impl_class
 sub run
 {
     my ($self, $c) = @_;
-    $self->resolver(Net::DNS::Resolver->new);
     $self->impl->run($c);
 }
 
@@ -60,16 +61,17 @@ sub send_request
 {
     my ($self, $c, $request) = @_;
 
-    if ($request->requires_name_lookup) {
+    if ($self->resolver && $request->requires_name_lookup) {
         $self->lookup_host($c, $request);
     } else {
         $request->uri->host( $request->notes('resolved_ip') )
             if $request->notes('resolved_ip');
-        if ( $self->block_private_ip_address($c, $request, $request->uri)) {
+        if ( ! $c->request_is_allowed($request)) {
             return;
         }
         $self->start_request($c, $request);
     }
+    return 1;
 }
 
 sub handle_response
@@ -79,7 +81,7 @@ sub handle_response
         # Put it back
         $req->uri->host($host);
     }
-    $c->handle_response($req, $res);
+    $c->handle_response($req, $c->prepare_response($res) );
 }
 
 sub lookup_host
@@ -115,7 +117,7 @@ sub start_request
         $self->handle_response(
             $c,
             $req,
-            $self->_http_error(500, "Failed to connect to " . $uri->host . ": $@
+            $c->_http_error(500, "Failed to connect to " . $uri->host . ": $@
 ", $req)
         );
         return;
@@ -132,7 +134,7 @@ sub start_request
 
             if ($st == 0) {
                 my $res = $parser->object;
-                $c->run_hook('engine.handle_response', { request => $req, response => $res });
+                $c->notify('engine.handle_response', { request => $req, response => $res });
                 $self->handle_response($c, $notifier->{request}, $res);
                 $notifier->handle_closed();
                 $self->impl->remove($notifier);
@@ -140,13 +142,13 @@ sub start_request
         },
         on_read_error => sub {
             my $notifier = shift;
-            my $res = $self->_http_error(400, "incomplete response", $notifier->{request});
+            my $res = $c->_http_error(400, "incomplete response", $notifier->{request});
             $c->handle_response($c, $notifier->{request}, $res);
         },
         on_write_error => sub {
             my $notifier = shift;
-            my $res = $self->_http_error(500, "Could not write to socket ", $notifier->{request});
-            $c->run_hook('engine.handle_response', { request => $req, response => $res });
+            my $res = $c->_http_error(500, "Could not write to socket ", $notifier->{request});
+            $c->notify('engine.handle_response', { request => $req, response => $res });
             $self->handle_response($c, $notifier->{request}, $res);
         }
     );
@@ -155,7 +157,7 @@ sub start_request
     $buffer->{parser}  = HTTP::Parser->new(response => 1);
     $buffer->{request} = $req;
 
-    $c->run_hook('engine.send_request', { request => $req });
+    $c->notify('engine.send_request', { request => $req });
     $buffer->send($req->format);
     $self->impl->add($buffer);
 }
@@ -202,6 +204,16 @@ __END__
 
 Gungho::Engine::IO::Async - IO::Async Engine
 
+=head1 SYNOPSIS
+
+  engine:
+    module: IO::Async
+    config:
+        loop_delay: 0.01
+        dns:
+            disable: 1 # Only if you don't want Gungho to resolve DNS
+
+
 =head1 DESCRIPTION
 
 This class uses IO::Async to dispatch requests.
