@@ -13,15 +13,19 @@ sub run
 
     Gungho::Inline->run(
         {
+            user_agent => "Install Test For Gungho $Gungho::VERSION",
             engine => {
                 module => $engine,
             },
-            block_private_ip_address => 1,
+            components => [
+                'BlockPrivateIP'
+            ]
         },
         {
             provider => sub {
                 my($p, $c) = @_;
-                $p->add_request(Gungho::Request->new(GET => $_)) for qw(
+
+                $c->send_request(Gungho::Request->new(GET => $_)) for qw(
                     http://10.0.0.1
                     http://10.255.255.254
                     http://127.0.0.1
